@@ -174,7 +174,7 @@ class SendGrid(object):
 
     def add_sendip(self, **fields):
         '''Fields can be task, user, set, ip'''
-        return self.call('sendip', 'add', dict(task="get", **fields))
+        return self.call('sendip', 'add', dict(task="append", **fields))
 
     def warm_up_from_csv(self,
                         csv_path,  # name, email csv string (no header)
